==> constructorio-ui-quizzes-1.3.11.tgz: package/lib/mjs/components/SelectTypeQuestion/SelectTypeQuestion.js <==
import React, { useEffect, useState, useContext } from 'react';
import QuestionTitle from '../QuestionTitle/QuestionTitle';
import QuestionDescription from '../QuestionDescription/QuestionDescription';
import QuizContext from '../CioQuiz/context';
import { renderImages } from '../../utils';
import { QuestionTypes } from '../CioQuiz/actions';
import ControlBar from '../ControlBar/ControlBar';
function SelectTypeQuestion() {
    const { state, nextQuestion, previousQuestion } = useContext(QuizContext);
    let question;
    let type;
    let hasImages = false;
    let instructions;
    if (state?.quiz.currentQuestion) {
        question = state.quiz.currentQuestion.next_question;
        type = question.type;
        hasImages = question.options.some((option) => option.images);
        instructions = type === QuestionTypes.MultipleSelect && 'Select one or more options';
    }
    const [selected, setSelected] = useState({});
    const isDisabled = Object.keys(selected).length === 0;
    useEffect(() => {
        if (state?.quiz.currentQuestion?.next_question?.type) {
            const nextQuestionId = state.quiz.currentQuestion.next_question.id;
            const answers = state.answers?.inputs?.[nextQuestionId] || [];
            const prevSelected = {};
            answers?.forEach((answer) => {
                prevSelected[Number(answer)] = true;
            });
            setSelected(prevSelected);
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [state?.quiz.currentQuestion?.next_question.id]);
    const toggleIdSelected = (id) => {
        if (type === QuestionTypes.SingleSelect && nextQuestion) {
            setSelected({ [id]: true });
            nextQuestion([id.toString()]);
        }
        else if (type === QuestionTypes.MultipleSelect) {
            if (selected[id]) {
                const newState = { ...selected };
                delete newState[id];
                setSelected(newState);
            }
            else {
                setSelected({ ...selected, [id]: true });
            }
        }
    };
    const onOptionKeyDown = (event, id) => {
        if (event?.key === ' ' || event?.key === 'Enter') {
            toggleIdSelected(id);
        }
    };
    const onNextClick = () => {
        if (nextQuestion && !isDisabled && state?.quiz.currentQuestion) {
            const selectedAnswers = Object.keys(selected).filter((key) => selected[Number(key)]);
            nextQuestion(selectedAnswers);
        }
    };
    if (question) {
        return (React.createElement("div", { className: 'cio-select-question-container', "data-question-key": question.key },
            React.createElement("div", { className: 'cio-select-question-text' },
                React.createElement(QuestionTitle, { title: question.title }),
                question?.description ? React.createElement(QuestionDescription, { description: question.description }) : ''),
            instructions && React.createElement("div", { className: 'cio-select-question-instructions' }, instructions),
            React.createElement("div", { className: `${!hasImages
                    ? 'cio-question-options-container-text-only'
                    : 'cio-question-options-container'}` }, question?.options?.map((option) => (React.createElement("div", { className: `${!hasImages
                    ? 'cio-question-option-container-text-only'
                    : 'cio-question-option-container'} ${selected[option.id] ? 'selected' : ''}`, "data-question-option-key": option.key, onClick: () => {
                    toggleIdSelected(option.id);
                }, onKeyDown: (event) => {
                    onOptionKeyDown(event, option.id);
                }, role: 'button', tabIndex: 0, key: option.id },
                option.images ? renderImages(option.images, 'cio-question-option-image') : '',
                React.createElement("div", { className: 'cio-question-option-value' }, option?.value))))),
            React.createElement(ControlBar, { nextButtonHandler: onNextClick, isNextButtonDisabled: isDisabled, backButtonHandler: previousQuestion, showBackButton: !state?.quiz.isFirstQuestion, ctaButtonText: question?.cta_text })));
    }
    return null;
}
export default SelectTypeQuestion;

==> constructorio-ui-quizzes-1.4.0.tgz: package/lib/mjs/components/SelectTypeQuestion/SelectTypeQuestion.js <==
import React, { useContext } from 'react';
import QuestionTitle from '../QuestionTitle/QuestionTitle';
import QuestionDescription from '../QuestionDescription/QuestionDescription';
import QuizContext from '../CioQuiz/context';
import { renderImages } from '../../utils';
import ControlBar from '../ControlBar/ControlBar';
import { QuestionTypes } from '../CioQuiz/actions';
function SelectTypeQuestion() {
    const { state, getSelectInputProps } = useContext(QuizContext);
    let question;
    let hasImages = false;
    let instructions;
    if (state?.quiz.currentQuestion) {
        question = state.quiz.currentQuestion.next_question;
        hasImages = question.options.some((option) => option.images);
        instructions = question.type === QuestionTypes.MultipleSelect && 'Select one or more options';
    }
    if (question) {
        return (React.createElement("div", { className: 'cio-select-question-container', "data-question-key": question.key },
            React.createElement("div", { className: 'cio-select-question-text' },
                React.createElement(QuestionTitle, { title: question.title }),
                question?.description ? React.createElement(QuestionDescription, { description: question.description }) : ''),
            instructions && React.createElement("div", { className: 'cio-select-question-instructions' }, instructions),
            React.createElement("div", { className: `${!hasImages
                    ? 'cio-question-options-container-text-only'
                    : 'cio-question-options-container'}` }, question?.options?.map((option) => getSelectInputProps && (React.createElement("div", { ...getSelectInputProps(option) },
                option.images ? renderImages(option.images, 'cio-question-option-image') : '',
                React.createElement("div", { className: 'cio-question-option-value' }, option?.value))))),
            React.createElement(ControlBar, { ctaButtonText: question?.cta_text || 'Continue' })));
    }
    return null;
}
export default SelectTypeQuestion;
